/* Universal-Sequenzer speziell für SHF-EME, aber auch andere Anwendungen
 * 
 * V01.00 2024-02-02 DL1SUZ - Uwe
 * Email: dl1suz@darc.de
 * 
 * Hardwarebasis: ATTINY85 o.ä.
 * PCB-Layout DL1SUZ
 * 
 1. OUT_Relais schaltet "EIN" direkt mit IN_PTT
 2. OUT_PTT schaltet "EIN" mit Verzögerung, wenn INP_RM_Relais und INPUT_PTT "EIN" sind
 3. OUT_PTT schaltet "AUS" wenn einer der Eingänge auf "AUS" geht
 4. OUT_Relais schaltet mit Verzögerung "AUS", wenn Input_PTT "AUS" ist

 Wenn kein Rückmeldekontakt vorhanden ist wird der Eingang auf "betätigt" verdrahtet.

 Für die Messung des Sonnenrauschen kann als Referenz der Eingang des VV auf 50Ohm geschaltet werden.
 Hierfür wurde der Eingang IN-Measure vorbereitet. Bei Aktivierung wird OUT_Relais geschaltet.
 Ein Ansteuerung von OUT_PTT wird verhindert.
 */
 
 #include "timer.h"

//Instanzen von Timer ertellen
 Timer TON_01;                    //Einschaltverzögerung 
 Timer TOF_01;                    //Ausschaltverzögerung

//Vereinbarungen
  #define DELAY 100               //Verzögerungszeit 100ms
  const byte IN_PTT = 2;
  const byte IN_RM_Relais = 3;
  const byte IN_Measure = 4;
  const byte OUT_Relais = 0;
  const byte OUT_PTT = 1;
  bool state_IN_PTT;
  bool state_IN_RM_Relais;
  bool state_IN_Measure;
  unsigned long time_IN_PTT;
  
void setup() {
  pinMode(IN_PTT, INPUT_PULLUP);
  pinMode(IN_RM_Relais, INPUT_PULLUP);
  pinMode(IN_Measure, INPUT_PULLUP);
  pinMode(OUT_PTT, OUTPUT);
  pinMode(OUT_Relais, OUTPUT);
  digitalWrite(OUT_PTT,LOW);
  digitalWrite(OUT_Relais,LOW); 
}

void loop() {
 state_IN_Measure = !(digitalRead (IN_Measure)); 
 state_IN_PTT = !(digitalRead (IN_PTT)); 
 state_IN_RM_Relais = !(digitalRead (IN_RM_Relais));  
 digitalWrite(OUT_Relais, TOF_01.delayOff((state_IN_Measure || state_IN_PTT),DELAY));
 digitalWrite(OUT_PTT, TON_01.delayOn((!state_IN_Measure && state_IN_PTT && state_IN_RM_Relais),DELAY)); 
}
